@@ -13,7 +13,7 @@ import zc.recipe.egg
 logger = logging.getLogger(__name__)
 
 MONGO_BINARIES = (
-    'mongo', 'mongodb', 'mongodump', 'mongoexport',
+    'mongo', 'mongod', 'mongodump', 'mongoexport',
     'mongofiles', 'mongoimport', 'mongorestore', 'mongos',
     'mongosniff', 'mongostat'
 )
